package com.jwl.driver.server.controller;


import com.jwl.driver.server.dto.DriverSchoolDto;
import com.jwl.driver.server.dto.LoginUserDto;
import com.jwl.driver.server.exception.BusinessException;
import com.jwl.driver.server.response.BaseResponse;
import com.jwl.driver.server.service.ITdSysUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.springframework.stereotype.Controller;

import javax.validation.Valid;
import java.time.LocalDateTime;
import java.util.Objects;

/**
 * <p>
 * 用户表; 前端控制器
 * </p>
 *
 * @author Automated procedures
 * @since 2023-08-10
 */
@RestController
@Api(tags = "用户管理")
@RequestMapping("/tdSysUser")
@Slf4j
public class TdSysUserController {

    @Autowired
    private ITdSysUserService userService;

    @ApiOperation("获取验证码")
    @GetMapping("/code")
    public BaseResponse code(@RequestParam String phone) {
        log.info("获取验证码======>phone:{}", phone);
        return BaseResponse.success(userService.code(phone));
    }

    @ApiOperation("用户登陆")
    @PostMapping("/login")
    public BaseResponse login(@RequestBody @Valid LoginUserDto loginUserDto) {
        log.info("用户登录======>loginUserDto:{}", loginUserDto);
        return BaseResponse.success(userService.login(loginUserDto));
    }

    @ApiOperation("用户登出")
    @GetMapping("/loginOut")
    public BaseResponse loginOut(){
        log.info("用户登出======>{}", LocalDateTime.now());
        return BaseResponse.success(userService.loginOut());
    }

    @ApiOperation("获取用户信息")
    @GetMapping("/queryUserMessage")
    public BaseResponse queryUserMessage() {
        log.info("获取用户信息======>");
        return BaseResponse.success(userService.queryUserMessage());
    }

    @ApiOperation("用户绑定驾校")
    @PostMapping("/bindSchool")
    public BaseResponse bindSchool(@RequestBody @Valid DriverSchoolDto schoolDto) {
        log.info("用户绑定驾校信息======>schoolDto{}",schoolDto);
        return BaseResponse.success(userService.bindSchool(schoolDto));
    }


}
