package com.jwl.driver.server.filter;

import cn.hutool.core.util.StrUtil;
import com.jwl.driver.server.util.TokenThreadUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;
import org.springframework.web.filter.OncePerRequestFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * 线程保持当前token
 */
@Component
public class TokenFilter extends OncePerRequestFilter {
    private static final Logger log = LoggerFactory.getLogger(TokenFilter.class);


    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain) throws ServletException, IOException {
        //移除线程变量里的缓存值
        TokenThreadUtil.remove();

        String requestTokenHeader = request.getHeader("Authorization");
        if (StrUtil.isBlank(requestTokenHeader)) {
            log.warn("Bearer token 为空");
            filterChain.doFilter((ServletRequest) request, (ServletResponse) response);
            return;
        }

        TokenThreadUtil.setToken(requestTokenHeader);
        filterChain.doFilter(request, response);
    }
}
