package com.jwl.driver.server.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.generator.config.IFileCreate;
import com.jwl.driver.server.constant.Constants;
import com.jwl.driver.server.dto.QuestionQueryDto;
import com.jwl.driver.server.entity.TdQuestion;
import com.jwl.driver.server.entity.TdSysConfigList;
import com.jwl.driver.server.mapper.TdQuestionMapper;
import com.jwl.driver.server.service.ITdQuestionService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jwl.driver.server.service.ITdSysConfigListService;
import com.jwl.driver.server.service.ITdSysConfigService;
import com.jwl.driver.server.vo.QuestionVo;
import com.jwl.driver.server.vo.QusetionCategoryVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 题库; 服务实现类
 * </p>
 *
 * @author Automated procedures
 * @since 2023-08-10
 */
@Service
public class TdQuestionServiceImpl extends ServiceImpl<TdQuestionMapper, TdQuestion> implements ITdQuestionService {

    @Autowired
    private ITdSysConfigService configService;

    @Autowired
    private ITdSysConfigListService configListService;

    @Override
    public QuestionVo queryQuestionById(QuestionQueryDto queryDto) {
        QuestionQueryDto newDto = new QuestionQueryDto()
                .setQuestionId(queryDto.getQuestionId());
        List<QuestionVo> questionVos = queryQuestion(newDto);
        return CollectionUtil.isEmpty(questionVos)? null : questionVos.get(0);
    }

    @Override
    public List<QuestionVo> queryQuestionByIdList(QuestionQueryDto queryDto) {
        QuestionQueryDto newDto = new QuestionQueryDto()
                .setQuestionIdList(queryDto.getQuestionIdList());
        return queryQuestion(newDto);
    }

    @Override
    public List<QuestionVo> queryQuestion(QuestionQueryDto queryDto) {
        List<QuestionVo> questionVos = this.getBaseMapper().queryQuestion(queryDto);
        questionOptionHandler(questionVos);
        return questionVos;
    }

    @Override
    public List<QuestionVo> getTestQuestion(QuestionQueryDto queryDto) {
        List<QuestionVo> resultList = new ArrayList<>();

        if (StrUtil.equals(Constants.SUBJECT_ONE,queryDto.getSubject())){
            //40道判断题 60道单选 每题1分
            queryDto.setType(Constants.QUESTION_TYPE_ONE)
                    .setNum(60);
            resultList.addAll(this.getBaseMapper().queryQuestionByRandom(queryDto));

            queryDto.setType(Constants.QUESTION_TYPE_TWO)
                    .setNum(40);
            resultList.addAll(this.getBaseMapper().queryQuestionByRandom(queryDto));

        }else if(StrUtil.equals(Constants.SUBJECT_FOUR,queryDto.getSubject())){
            //20道判断题 20道单选 10道多选，每题2分，如果各车型不统一 可以配在数据库里
            queryDto.setType(Constants.QUESTION_TYPE_TWO)
                    .setNum(20);

            resultList.addAll(this.getBaseMapper().queryQuestionByRandom(queryDto));
            queryDto.setType(Constants.QUESTION_TYPE_ONE)
                    .setNum(20);

            resultList.addAll(this.getBaseMapper().queryQuestionByRandom(queryDto));
            queryDto.setType(Constants.QUESTION_TYPE_THREE)
                    .setNum(10);
            resultList.addAll(this.getBaseMapper().queryQuestionByRandom(queryDto));
        }
        questionOptionHandler(resultList);
        return resultList;
    }

    @Override
    public List<QusetionCategoryVo> questionCategory(QuestionQueryDto queryDto) {

        List<QusetionCategoryVo> resultList = new ArrayList<>();
        //获取题目
        List<QuestionVo> tdQuestionVos = queryQuestionByIdList(queryDto);
        if (CollectionUtil.isEmpty(tdQuestionVos)){
            return resultList;
        }
        //获取分类
        List<TdSysConfigList> categoryList = configListService.querySysConfigList(Constants.QUESTION_CATEGORY, Constants.DEFAULT_CARTYPE_ID);
        Map<String, String> categoryMap = categoryList.stream().collect(Collectors.toMap(TdSysConfigList::getConfigItemCode, TdSysConfigList::getConfigItemName, (v1, v2) -> v1));
        Map<String,Integer> totalMap = new HashMap<>();

        for (QuestionVo tdQuestionVo : tdQuestionVos) {
            String category = tdQuestionVo.getCategory();
            if (StrUtil.isBlank(category)){
                continue;
            }
            String[] split = category.split(",");
            for (String s : split) { //遍历字符串数组
                if (totalMap.containsKey(s)) { //判断Map集合中是否有该字符
                    Integer value = totalMap.get(s); //通过key找出集合中的value
                    totalMap.put(s, value + 1); //将值的数据加1，然后添加到集合中去
                } else {
                    totalMap.put(s,1); //此时集合中没有该Key,所以将该字符作为键加入到集合中
                }
            }
        }

        for (String category : totalMap.keySet()) {
            QusetionCategoryVo categoryVo = new QusetionCategoryVo()
                    .setCategory(category)
                    .setCategoryName(categoryMap.getOrDefault(category,"其他类型"))
                    .setNum(totalMap.get(category));
            resultList.add(categoryVo);
        }
        return resultList;
    }

    @Override
    public int updateQuestion(QuestionVo questionVo) {
        return this.getBaseMapper().updateQuestion(questionVo);
    }

    /**
     * 问题选项规整
     */
    private void questionOptionHandler(List<QuestionVo> questionVos){
        if (CollectionUtil.isNotEmpty(questionVos)){
            for (QuestionVo questionVo : questionVos) {
                //如果选项A没有值 则为判断题
                List<QuestionVo.QuestionOption> optionList = new ArrayList<>();
                if (StrUtil.isBlank(questionVo.getChooseA())){
                    optionList.add(new QuestionVo.QuestionOption("A","正确","1"));
                    optionList.add(new QuestionVo.QuestionOption("B","错误","2"));
                }else {
                    //起码ABCD都有
                    optionList.add(new QuestionVo.QuestionOption("A",questionVo.getChooseA(),"1"));
                    optionList.add(new QuestionVo.QuestionOption("B",questionVo.getChooseB(),"2"));
                    optionList.add(new QuestionVo.QuestionOption("C",questionVo.getChooseC(),"3"));
                    optionList.add(new QuestionVo.QuestionOption("D",questionVo.getChooseD(),"4"));

                    if (StrUtil.isNotBlank(questionVo.getChooseE())){
                        optionList.add(new QuestionVo.QuestionOption("E",questionVo.getChooseE(),"5"));
                    }
                    if (StrUtil.isNotBlank(questionVo.getChooseF())){
                        optionList.add(new QuestionVo.QuestionOption("F",questionVo.getChooseF(),"6"));
                    }
                    if (StrUtil.isNotBlank(questionVo.getChooseG())){
                        optionList.add(new QuestionVo.QuestionOption("G",questionVo.getChooseG(),"7"));
                    }
                }
                questionVo.setOptionList(optionList);
            }
        }
    }
}
