package com.jwl.driver.server.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.jwl.driver.server.constant.Constants;
import com.jwl.driver.server.entity.TdSysConfigList;
import com.jwl.driver.server.mapper.TdSysConfigListMapper;
import com.jwl.driver.server.service.ITdSysConfigListService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 系统配置列表; 服务实现类
 * </p>
 *
 * @author Automated procedures
 * @since 2023-08-10
 */
@Service
public class TdSysConfigListServiceImpl extends ServiceImpl<TdSysConfigListMapper, TdSysConfigList> implements ITdSysConfigListService {

    @Override
    public List<TdSysConfigList> querySysConfigList(String configKey, Integer carTypeId) {
        LambdaQueryWrapper<TdSysConfigList> queryWrapper = new LambdaQueryWrapper<TdSysConfigList>()
                .eq(TdSysConfigList::getCarTypeId, carTypeId)
                .eq(TdSysConfigList::getConfigKey, configKey)
                .eq(TdSysConfigList::getIsActive, Constants.IS_ACTIVE_TRUE)
                .orderByAsc(TdSysConfigList::getShowOrder);

        return this.getBaseMapper().selectList(queryWrapper);
    }

    @Override
    public Map<String, Map<String, String>> querySysConfigMap(List<String> configKeyList, Integer carTypeId) {

        Map<String, Map<String, String>> resultMap = new HashMap<>();
        LambdaQueryWrapper<TdSysConfigList> queryWrapper = new LambdaQueryWrapper<TdSysConfigList>()
                .eq(TdSysConfigList::getCarTypeId, carTypeId)
                .in(TdSysConfigList::getConfigKey, configKeyList)
                .eq(TdSysConfigList::getIsActive, Constants.IS_ACTIVE_TRUE);

        List<TdSysConfigList> configLists = this.getBaseMapper().selectList(queryWrapper);
        for (String configKey : configKeyList) {
            Map<String, String> collect = configLists.stream().filter(s -> StrUtil.equals(s.getConfigKey(), configKey))
                    .sorted(Comparator.comparing(TdSysConfigList::getShowOrder))
                    .collect(Collectors.toMap(TdSysConfigList::getConfigItemCode, TdSysConfigList::getConfigItemName));
            resultMap.put(configKey, collect);
        }
        return resultMap;
    }
}
