package com.jwl.driver.server.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.jwl.driver.server.constant.Constants;
import com.jwl.driver.server.entity.TdSysConfig;
import com.jwl.driver.server.mapper.TdSysConfigMapper;
import com.jwl.driver.server.service.ITdSysConfigService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 系统配置表; 服务实现类
 * </p>
 *
 * @author Automated procedures
 * @since 2023-08-10
 */
@Service
@Slf4j
public class TdSysConfigServiceImpl extends ServiceImpl<TdSysConfigMapper, TdSysConfig> implements ITdSysConfigService {

    @Override
    public TdSysConfig queryConfigByKey(String configKey, Integer carTypeId) {
        log.info("获取系统配置参数，configKey：{}", configKey);
        LambdaQueryWrapper<TdSysConfig> queryWrapper = new QueryWrapper<TdSysConfig>().lambda()
                .eq(TdSysConfig::getCarTypeId,carTypeId)
                .eq(TdSysConfig::getConfigKey, configKey)
                .eq(TdSysConfig::getIsActive, Constants.IS_ACTIVE_TRUE);
        return getOne(queryWrapper);
    }

    @Override
    public String queryConfigValueByKey(String configKey, Integer carTypeId) {
        log.info("获取系统配置参数，configKey：{}", configKey);
        LambdaQueryWrapper<TdSysConfig> queryWrapper = new QueryWrapper<TdSysConfig>().lambda()
                .eq(TdSysConfig::getCarTypeId,carTypeId)
                .eq(TdSysConfig::getConfigKey, configKey)
                .eq(TdSysConfig::getIsActive, Constants.IS_ACTIVE_TRUE);
        TdSysConfig config = getOne(queryWrapper);
        if(null == config) {
            return null;
        }
        return config.getConfigValue();
    }

    @Override
    public Map<String, TdSysConfig> queryConfigByKeys(List<String> configKeyList,Integer carTypeId) {
        log.info("获取系统配置参数，configKeyList：{}", configKeyList);
        LambdaQueryWrapper<TdSysConfig> queryWrapper = new QueryWrapper<TdSysConfig>().lambda()
                .eq(TdSysConfig::getCarTypeId,carTypeId)
                .in(TdSysConfig::getConfigKey, configKeyList)
                .eq(TdSysConfig::getIsActive, Constants.IS_ACTIVE_TRUE);
        List<TdSysConfig> configList = list(queryWrapper);

        if(CollectionUtil.isEmpty(configList)) {
            return Collections.EMPTY_MAP;
        }
        return configList.stream().collect(Collectors.toMap(TdSysConfig::getConfigKey, sysConfig -> sysConfig));
    }
}
